@@ -30,6 +30,12 @@
 #ifndef BITTORRENT_TORRENTHANDLE_H
 #define BITTORRENT_TORRENTHANDLE_H
 
+#include <functional>
+
+#include <libtorrent/fwd.hpp>
+#include <libtorrent/torrent_handle.hpp>
+#include <libtorrent/torrent_status.hpp>
+
 #include <QDateTime>
 #include <QHash>
 #include <QObject>
@@ -38,55 +44,25 @@
 #include <QString>
 #include <QVector>
 
-#include <libtorrent/torrent_handle.hpp>
-#include <libtorrent/version.hpp>
-#if LIBTORRENT_VERSION_NUM >= 10100
-#include <libtorrent/torrent_status.hpp>
-#endif
-
-#include <boost/function.hpp>
-
-#include "base/tristatebool.h"
 #include "private/speedmonitor.h"
 #include "infohash.h"
 #include "torrentinfo.h"
 
-class QBitArray;
-class QStringList;
-template<typename T, typename U> struct QPair;
-
 extern const QString QB_EXT;
 
-namespace libtorrent
-{
-    class alert;
-    struct stats_alert;
-    struct torrent_checked_alert;
-    struct torrent_finished_alert;
-    struct torrent_paused_alert;
-    struct torrent_resumed_alert;
-    struct save_resume_data_alert;
-    struct save_resume_data_failed_alert;
-    struct file_renamed_alert;
-    struct file_rename_failed_alert;
-    struct storage_moved_alert;
-    struct storage_moved_failed_alert;
-    struct metadata_received_alert;
-    struct file_completed_alert;
-    struct tracker_error_alert;
-    struct tracker_reply_alert;
-    struct tracker_warning_alert;
-    struct fastresume_rejected_alert;
-    struct torrent_status;
-}
+class QBitArray;
+class QDateTime;
+class QStringList;
+class QUrl;
 
 namespace BitTorrent
 {
-    struct PeerAddress;
-    class Session;
+    enum class DownloadPriority;
     class PeerInfo;
+    class Session;
     class TrackerEntry;
     struct AddTorrentParams;
+    struct PeerAddress;
 
     struct CreateTorrentParams
     {
@@ -107,19 +83,26 @@ namespace BitTorrent
         int uploadLimit;
         int downloadLimit;
         // for new torrents
-        QVector<int> filePriorities;
+        QVector<DownloadPriority> filePriorities;
+        QDateTime addedTime;
         // for restored torrents
         qreal ratioLimit;
         int seedingTimeLimit;
 
         CreateTorrentParams();
-        CreateTorrentParams(const AddTorrentParams &params);
+        explicit CreateTorrentParams(const AddTorrentParams &params);
     };
 
     struct TrackerInfo
     {
         QString lastMessage;
-        quint32 numPeers = 0;
+        int numPeers = 0;
+    };
+
+    enum class MoveStorageMode
+    {
+        KeepExistingFiles,
+        Overwrite
     };
 
     enum class TorrentState
@@ -136,9 +119,6 @@ namespace BitTorrent
         Uploading,
         StalledUploading,
 
-#if LIBTORRENT_VERSION_NUM < 10100
-        QueuedForChecking,
-#endif
         CheckingResumeData,
         QueuedDownloading,
         QueuedUploading,
@@ -155,6 +135,8 @@ namespace BitTorrent
         Error
     };
 
+    uint qHash(TorrentState key, uint seed);
+
     class TorrentHandle : public QObject
     {
         Q_DISABLE_COPY(TorrentHandle)
@@ -170,7 +152,7 @@ namespace BitTorrent
         static const qreal MAX_RATIO;
         static const int MAX_SEEDING_TIME;
 
-        TorrentHandle(Session *session, const libtorrent::torrent_handle &nativeHandle,
+        TorrentHandle(Session *session, const lt::torrent_handle &nativeHandle,
                           const CreateTorrentParams &params);
         ~TorrentHandle();
 
@@ -265,7 +247,7 @@ namespace BitTorrent
         qlonglong fileSize(int index) const;
         QStringList absoluteFilePaths() const;
         QStringList absoluteFilePathsUnwanted() const;
-        QVector<int> filePriorities() const;
+        QVector<DownloadPriority> filePriorities() const;
 
         TorrentInfo info() const;
         bool isSeed() const;
@@ -288,16 +270,16 @@ namespace BitTorrent
         bool hasError() const;
         bool hasFilteredPieces() const;
         int queuePosition() const;
-        QList<TrackerEntry> trackers() const;
+        QVector<TrackerEntry> trackers() const;
         QHash<QString, TrackerInfo> trackerInfos() const;
-        QList<QUrl> urlSeeds() const;
+        QVector<QUrl> urlSeeds() const;
         QString error() const;
         qlonglong totalDownload() const;
         qlonglong totalUpload() const;
-        int activeTime() const;
-        int finishedTime() const;
-        int seedingTime() const;
-        qulonglong eta() const;
+        qlonglong activeTime() const;
+        qlonglong finishedTime() const;
+        qlonglong seedingTime() const;
+        qlonglong eta() const;
         QVector<qreal> filesProgress() const;
         int seedsCount() const;
         int peersCount() const;
@@ -309,13 +291,13 @@ namespace BitTorrent
         int incompleteCount() const;
         QDateTime lastSeenComplete() const;
         QDateTime completedTime() const;
-        int timeSinceUpload() const;
-        int timeSinceDownload() const;
-        int timeSinceActivity() const;
+        qlonglong timeSinceUpload() const;
+        qlonglong timeSinceDownload() const;
+        qlonglong timeSinceActivity() const;
         int downloadLimit() const;
         int uploadLimit() const;
         bool superSeeding() const;
-        QList<PeerInfo> peers() const;
+        QVector<PeerInfo> peers() const;
         QBitArray pieces() const;
         QBitArray downloadingPieces() const;
         QVector<int> pieceAvailability() const;
@@ -332,7 +314,7 @@ namespace BitTorrent
         qlonglong nextAnnounce() const;
 
         void setName(const QString &name);
-        void setSequentialDownload(bool b);
+        void setSequentialDownload(bool enable);
         void toggleSequentialDownload();
         void setFirstLastPiecePriority(bool enabled);
         void toggleFirstLastPiecePriority();
@@ -342,22 +324,18 @@ namespace BitTorrent
         void forceReannounce(int index = -1);
         void forceDHTAnnounce();
         void forceRecheck();
-#if LIBTORRENT_VERSION_NUM < 10100
-        void setTrackerLogin(const QString &username, const QString &password);
-#endif
         void renameFile(int index, const QString &name);
-        bool saveTorrentFile(const QString &path);
-        void prioritizeFiles(const QVector<int> &priorities);
+        void prioritizeFiles(const QVector<DownloadPriority> &priorities);
         void setRatioLimit(qreal limit);
         void setSeedingTimeLimit(int limit);
         void setUploadLimit(int limit);
         void setDownloadLimit(int limit);
         void setSuperSeeding(bool enable);
-        void flushCache();
-        void addTrackers(const QList<TrackerEntry> &trackers);
-        void replaceTrackers(const QList<TrackerEntry> &trackers);
-        void addUrlSeeds(const QList<QUrl> &urlSeeds);
-        void removeUrlSeeds(const QList<QUrl> &urlSeeds);
+        void flushCache() const;
+        void addTrackers(const QVector<TrackerEntry> &trackers);
+        void replaceTrackers(const QVector<TrackerEntry> &trackers);
+        void addUrlSeeds(const QVector<QUrl> &urlSeeds);
+        void removeUrlSeeds(const QVector<QUrl> &urlSeeds);
         bool connectPeer(const PeerAddress &peerAddress);
 
         QString toMagnetUri() const;
@@ -365,14 +343,15 @@ namespace BitTorrent
         bool needSaveResumeData() const;
 
         // Session interface
-        libtorrent::torrent_handle nativeHandle() const;
+        lt::torrent_handle nativeHandle() const;
 
-        void handleAlert(libtorrent::alert *a);
-        void handleStateUpdate(const libtorrent::torrent_status &nativeStatus);
+        void handleAlert(const lt::alert *a);
+        void handleStateUpdate(const lt::torrent_status &nativeStatus);
         void handleTempPathChanged();
         void handleCategorySavePathChanged();
         void handleAppendExtensionToggled();
         void saveResumeData();
+        void handleStorageMoved(const QString &newPath, const QString &errorMessage);
 
         /**
          * @brief fraction of file pieces that are available at least from one peer
@@ -383,7 +362,7 @@ namespace BitTorrent
         QVector<qreal> availableFileFractions() const;
 
     private:
-        typedef boost::function<void ()> EventTrigger;
+        typedef std::function<void ()> EventTrigger;
 
 #if (LIBTORRENT_VERSION_NUM < 10200)
         using LTFileIndex = int;
@@ -392,61 +371,49 @@ namespace BitTorrent
 #endif
 
         void updateStatus();
-        void updateStatus(const libtorrent::torrent_status &nativeStatus);
+        void updateStatus(const lt::torrent_status &nativeStatus);
         void updateState();
         void updateTorrentInfo();
 
-        void handleStorageMovedAlert(const libtorrent::storage_moved_alert *p);
-        void handleStorageMovedFailedAlert(const libtorrent::storage_moved_failed_alert *p);
-        void handleTrackerReplyAlert(const libtorrent::tracker_reply_alert *p);
-        void handleTrackerWarningAlert(const libtorrent::tracker_warning_alert *p);
-        void handleTrackerErrorAlert(const libtorrent::tracker_error_alert *p);
-        void handleTorrentCheckedAlert(const libtorrent::torrent_checked_alert *p);
-        void handleTorrentFinishedAlert(const libtorrent::torrent_finished_alert *p);
-        void handleTorrentPausedAlert(const libtorrent::torrent_paused_alert *p);
-        void handleTorrentResumedAlert(const libtorrent::torrent_resumed_alert *p);
-        void handleSaveResumeDataAlert(const libtorrent::save_resume_data_alert *p);
-        void handleSaveResumeDataFailedAlert(const libtorrent::save_resume_data_failed_alert *p);
-        void handleFastResumeRejectedAlert(const libtorrent::fastresume_rejected_alert *p);
-        void handleFileRenamedAlert(const libtorrent::file_renamed_alert *p);
-        void handleFileRenameFailedAlert(const libtorrent::file_rename_failed_alert *p);
-        void handleFileCompletedAlert(const libtorrent::file_completed_alert *p);
-        void handleMetadataReceivedAlert(const libtorrent::metadata_received_alert *p);
-        void handleStatsAlert(const libtorrent::stats_alert *p);
+        void handleFastResumeRejectedAlert(const lt::fastresume_rejected_alert *p);
+        void handleFileCompletedAlert(const lt::file_completed_alert *p);
+        void handleFileRenamedAlert(const lt::file_renamed_alert *p);
+        void handleFileRenameFailedAlert(const lt::file_rename_failed_alert *p);
+        void handleMetadataReceivedAlert(const lt::metadata_received_alert *p);
+        void handlePerformanceAlert(const lt::performance_alert *p) const;
+        void handleSaveResumeDataAlert(const lt::save_resume_data_alert *p);
+        void handleSaveResumeDataFailedAlert(const lt::save_resume_data_failed_alert *p);
+        void handleTorrentCheckedAlert(const lt::torrent_checked_alert *p);
+        void handleTorrentFinishedAlert(const lt::torrent_finished_alert *p);
+        void handleTorrentPausedAlert(const lt::torrent_paused_alert *p);
+        void handleTorrentResumedAlert(const lt::torrent_resumed_alert *p);
+        void handleTrackerErrorAlert(const lt::tracker_error_alert *p);
+        void handleTrackerReplyAlert(const lt::tracker_reply_alert *p);
+        void handleTrackerWarningAlert(const lt::tracker_warning_alert *p);
 
         void resume_impl(bool forced);
         bool isMoveInProgress() const;
-        QString nativeActualSavePath() const;
+        QString actualStorageLocation() const;
+        bool isAutoManaged() const;
+        void setAutoManaged(bool enable);
 
         void adjustActualSavePath();
         void adjustActualSavePath_impl();
-        void move_impl(QString path, bool overwrite);
-        void moveStorage(const QString &newPath, bool overwrite);
+        void move_impl(QString path, MoveStorageMode mode);
+        void moveStorage(const QString &newPath, MoveStorageMode mode);
         void manageIncompleteFiles();
-        bool addTracker(const TrackerEntry &tracker);
-        bool addUrlSeed(const QUrl &urlSeed);
-        bool removeUrlSeed(const QUrl &urlSeed);
-        void setFirstLastPiecePriorityImpl(bool enabled, const QVector<int> &updatedFilePrio = {});
+        void setFirstLastPiecePriorityImpl(bool enabled, const QVector<DownloadPriority> &updatedFilePrio = {});
 
         Session *const m_session;
-        libtorrent::torrent_handle m_nativeHandle;
-        libtorrent::torrent_status m_nativeStatus;
+        lt::torrent_handle m_nativeHandle;
+        lt::torrent_status m_nativeStatus;
         TorrentState m_state;
         TorrentInfo m_torrentInfo;
         SpeedMonitor m_speedMonitor;
 
         InfoHash m_hash;
 
-        struct
-        {
-            QString oldPath;
-            QString newPath;
-            // queuedPath is where files should be moved to,
-            // when current moving is completed
-            QString queuedPath;
-            bool queuedOverwrite = true;
-        } m_moveStorageInfo;
-
+        bool m_storageIsMoving = false;
         // m_moveFinishedTriggers is activated only when the following conditions are met:
         // all file rename jobs complete, all file move jobs complete
         QQueue<EventTrigger> m_moveFinishedTriggers;
@@ -471,21 +438,9 @@ namespace BitTorrent
         bool m_hasMissingFiles;
         bool m_hasRootFolder;
         bool m_needsToSetFirstLastPiecePriority;
-        bool m_needsToStartForced;
 
         QHash<QString, TrackerInfo> m_trackerInfos;
 
-        enum StartupState
-        {
-            Preparing, // torrent is preparing to start regular processing
-            Starting, // torrent is prepared and starting to perform regular processing
-            Started // torrent is performing regular processing
-        };
-        StartupState m_startupState = Preparing;
-        // Handle torrent state when it starts performing some service job
-        // being in Paused state so it might be unpaused internally and then paused again
-        bool m_pauseWhenReady;
-
         bool m_unchecked = false;
     };
 }
